@@ -39,7 +39,6 @@ from prompt_toolkit.key_binding import (
     KeyBindings,
     merge_key_bindings,
 )
-
 def modify_and_import(module_name, package, modification_func):
     import importlib
     import sys
@@ -50,8 +49,9 @@ def modify_and_import(module_name, package, modification_func):
     codeobj = compile(new_source, module.__spec__.origin, 'exec')
     exec(codeobj, module.__dict__)
     sys.modules[module_name] = module
+    return module
 
-auto_suggest = modify_and_import('key_binding.bindings.auto_suggest', 'prompt_toolkit', lambda src: src.replace('right',
+auto_suggest = modify_and_import('prompt_toolkit.key_binding.bindings.auto_suggest', None, lambda src: src.replace('right',
         'end'))
 load_auto_suggest_bindings = auto_suggest.load_auto_suggest_bindings
 
